@@ -1,6 +1,6 @@
 package Hubot::Scripts::blacklist;
 {
-  $Hubot::Scripts::blacklist::VERSION = '0.0.12';
+  $Hubot::Scripts::blacklist::VERSION = '0.0.13';
 }
 use strict;
 use warnings;
@@ -8,12 +8,16 @@ use Try::Tiny;
 
 sub load {
     my ( $class, $robot ) = @_;
-    $robot->brain->{data}{blacklist}{subscriber} = {};
-    $robot->brain->{data}{blacklist}{patterns} = [];
+    $robot->brain->{data}{blacklist}{subscriber} ||= {};
+    $robot->brain->{data}{blacklist}{patterns} ||= [];
+    print STDERR "you have to set env HUBOT_BLACKLIST_MANAGER" unless $ENV{HUBOT_BLACKLIST_MANAGER};
     $robot->respond(
         qr/blacklist add (.*)$/i,
         sub {
             my $msg = shift;
+
+            return unless checkPermission($robot, $msg);
+
             my $pattern = $msg->match->[0];
             try {
                 qr/$pattern/ and push @{ $robot->brain->{data}{blacklist}{patterns} }, $pattern;
@@ -47,6 +51,9 @@ sub load {
         qr/blacklist del(?:ete)? (\d+)$/i,
         sub {
             my $msg = shift;
+
+            return unless checkPermission($robot, $msg);
+
             my $index = $msg->match->[0];
             my @list = @{ $robot->brain->{data}{blacklist}{patterns} };
             if ($index > @list - 1) {
@@ -99,6 +106,23 @@ sub load {
     );
 }
 
+sub checkPermission {
+    my ($robot, $msg) = @_;
+    my @manager = split /,/, $ENV{HUBOT_BLACKLIST_MANAGER} || '';
+    unless (@manager) {
+        $msg->send("oops! no managers. " . $robot->name . "'s owner has to read the documentation");
+        return;
+    }
+
+    my $name = $msg->message->user->{name};
+    unless (grep { /$name/ } @manager) {
+        $msg->send("you don't have permission. to add blacklist, asking to managers: $ENV{HUBOT_BLACKLIST_MANAGER}");
+        return;
+    }
+
+    return 1;
+}
+
 sub notify {
     my ($robot, $res, $patt, @subs) = @_;
     for my $sub (@subs) {
@@ -118,8 +142,23 @@ Hubot::Scripts::blacklist
     hubot blacklist - show blacklist
     hubot blacklist add <pattern> - add pattern to blacklist
     hubot blacklist del <index> - delete pattern at blacklist[index]
-    hubot blacklist subscribe - robot will tell you when blacklist enter a room
-    hubot blacklist unsubscribe - robot will not tell you when blacklist enter a room anymore
+    hubot blacklist subscribe - robot will tell you when blacklist entering a room
+    hubot blacklist unsubscribe - robot will not tell you anymore when blacklist entering a room
+
+=head1 CONFIGURATION
+
+=over
+
+=item * HUBOT_BLACKLIST_MANAGER
+
+manager has permission which can add and delete to blacklist.
+separate by comma C<,>
+
+e.g.
+
+    export HUBOT_BLACKLIST_MANAGER='hshong,aanoaa'
+
+=back
 
 =head1 AUTHOR
 
